@@ -23,9 +23,11 @@
 
 namespace LibreNMS\Alert\Transport;
 
+use Exception;
 use LibreNMS\Alert\AlertUtil;
 use LibreNMS\Alert\Transport;
 use LibreNMS\Config;
+use LibreNMS\Exceptions\AlertTransportDeliveryException;
 
 class Mail extends Transport
 {
@@ -48,7 +50,11 @@ class Mail extends Transport
             $msg = preg_replace("/(?<!\r)\n/", "\r\n", $alert_data['msg']);
         }
 
-        return \LibreNMS\Util\Mail::send($emails, $alert_data['title'], $msg, $html, $this->config['bcc'] ?? false, $this->config['attach-graph'] ?? null);
+        try {
+            return \LibreNMS\Util\Mail::send($emails, $alert_data['title'], $msg, $html, $this->config['bcc'] ?? false, $this->config['attach-graph'] ?? null);
+        } catch (Exception $e) {
+            throw new AlertTransportDeliveryException($alert_data, 0, $e->getMessage());
+        }
     }
 
     public static function configTemplate(): array
