@@ -707,10 +707,12 @@ class IRCBot
                     $this->log("Auth for '" . $params[0] . "', ID: '" . $user->user_id . "', Token: '" . $token . "', Mail: '" . $user->email . "'");
                 }
 
-                if (Mail::send($user->email, 'LibreNMS IRC-Bot Authtoken', "Your Authtoken for the IRC-Bot:\r\n\r\n" . $token . "\r\n\r\n", false) === true) {
+                try {
+                    Mail::send($user->email, 'LibreNMS IRC-Bot Authtoken', "Your Authtoken for the IRC-Bot:\r\n\r\n" . $token . "\r\n\r\n");
+
                     return $this->respond('Token sent!');
-                } else {
-                    return $this->respond('Sorry, seems like mail doesnt like us.');
+                } catch (\Exception $e) {
+                    return $this->respond('Sorry, seems like mail doesnt like us. ' . $e->getMessage());
                 }
             } else {
                 return $this->respond('Who are you again?');
