@@ -34,7 +34,7 @@ class Stellar extends OS implements
         if (empty($client_ws_data)) {
             $total_clients = 0;
         } else {
-            $total_clients = sizeof($client_ws_data);
+            $total_clients = count($client_ws_data);
         }
 
         $combined_oid = sprintf('%s::%s', $device['hardware'], 'apClientWlanService');
@@ -75,7 +75,7 @@ class Stellar extends OS implements
             if (empty($client_ws_data)) {
                 $total_clients = 0;
             } else {
-                $total_clients = sizeof($client_ws_data);
+                $total_clients = count($client_ws_data);
             }
 
             foreach ($sensors as $sensor) {
