@@ -31,7 +31,6 @@ namespace LibreNMS\Snmptrap\Handlers;
 use App\Models\Device;
 use LibreNMS\Interfaces\SnmptrapHandler;
 use LibreNMS\Snmptrap\Trap;
-use Log;
 
 class RuckusSzClusterInService implements SnmptrapHandler
 {
@@ -46,6 +45,6 @@ class RuckusSzClusterInService implements SnmptrapHandler
     public function handle(Device $device, Trap $trap)
     {
         $clusterName = $trap->getOidData($trap->findOid('RUCKUS-SZ-EVENT-MIB::ruckusSZClusterName'));
-        Log::event("Smartzone cluster $clusterName is now in service", $device->device_id, 'trap', 2);
+        $trap->log("Smartzone cluster $clusterName is now in service");
     }
 }
