@@ -25,7 +25,6 @@
 
 namespace LibreNMS\Util;
 
-use Exception;
 use LibreNMS\Config;
 use LibreNMS\Exceptions\RrdGraphException;
 use PHPMailer\PHPMailer\PHPMailer;
@@ -69,68 +68,66 @@ class Mail
      * @param  string  $subject
      * @param  string  $message
      * @param  bool  $html
-     * @return bool|string
+     * @param  bool  $bcc
+     * @param  bool|null  $embedGraphs
+     * @return bool
+     *
+     * @throws \PHPMailer\PHPMailer\Exception if delivery fails
      */
-    public static function send($emails, $subject, $message, bool $html = false, bool $bcc = false, ?bool $embedGraphs = null)
+    public static function send($emails, $subject, $message, bool $html = false, bool $bcc = false, ?bool $embedGraphs = null): bool
     {
         if (is_array($emails) || ($emails = self::parseEmails($emails))) {
             d_echo("Attempting to email $subject to: " . implode('; ', array_keys($emails)) . PHP_EOL);
             $mail = new PHPMailer(true);
-            try {
-                $mail->Hostname = php_uname('n');
+            $mail->Hostname = php_uname('n');
 
-                foreach (self::parseEmails(Config::get('email_from')) as $from => $from_name) {
-                    $mail->setFrom($from, $from_name);
-                }
-
-                // add addresses
-                $addMethod = $bcc ? 'addBcc' : 'addAddress';
-                foreach ($emails as $email => $email_name) {
-                    $mail->$addMethod($email, $email_name);
-                }
-
-                $mail->Subject = $subject;
-                $mail->XMailer = Config::get('project_name');
-                $mail->CharSet = 'utf-8';
-                $mail->WordWrap = 76;
-                $mail->Body = $message;
-                if ($embedGraphs ?? Config::get('email_attach_graphs')) {
-                    self::embedGraphs($mail, $html);
-                }
-                if ($html) {
-                    $mail->isHTML();
-                }
-                switch (strtolower(trim(Config::get('email_backend')))) {
-                    case 'sendmail':
-                        $mail->Mailer = 'sendmail';
-                        $mail->Sendmail = Config::get('email_sendmail_path');
-                        break;
-                    case 'smtp':
-                        $mail->isSMTP();
-                        $mail->Host = Config::get('email_smtp_host');
-                        $mail->Timeout = Config::get('email_smtp_timeout');
-                        $mail->SMTPAuth = Config::get('email_smtp_auth');
-                        $mail->SMTPSecure = Config::get('email_smtp_secure');
-                        $mail->Port = Config::get('email_smtp_port');
-                        $mail->Username = Config::get('email_smtp_username');
-                        $mail->Password = Config::get('email_smtp_password');
-                        $mail->SMTPAutoTLS = Config::get('email_auto_tls');
-                        $mail->SMTPDebug = 0;
-                        break;
-                    default:
-                        $mail->Mailer = 'mail';
-                        break;
-                }
-
-                return $mail->send();
-            } catch (\PHPMailer\PHPMailer\Exception $e) {
-                return $e->errorMessage();
-            } catch (Exception $e) {
-                return $e->getMessage();
+            foreach (self::parseEmails(Config::get('email_from')) as $from => $from_name) {
+                $mail->setFrom($from, $from_name);
             }
+
+            // add addresses
+            $addMethod = $bcc ? 'addBcc' : 'addAddress';
+            foreach ($emails as $email => $email_name) {
+                $mail->$addMethod($email, $email_name);
+            }
+
+            $mail->Subject = $subject;
+            $mail->XMailer = Config::get('project_name');
+            $mail->CharSet = 'utf-8';
+            $mail->WordWrap = 76;
+            $mail->Body = $message;
+            if ($embedGraphs ?? Config::get('email_attach_graphs')) {
+                self::embedGraphs($mail, $html);
+            }
+            if ($html) {
+                $mail->isHTML();
+            }
+            switch (strtolower(trim(Config::get('email_backend')))) {
+                case 'sendmail':
+                    $mail->Mailer = 'sendmail';
+                    $mail->Sendmail = Config::get('email_sendmail_path');
+                    break;
+                case 'smtp':
+                    $mail->isSMTP();
+                    $mail->Host = Config::get('email_smtp_host');
+                    $mail->Timeout = Config::get('email_smtp_timeout');
+                    $mail->SMTPAuth = Config::get('email_smtp_auth');
+                    $mail->SMTPSecure = Config::get('email_smtp_secure');
+                    $mail->Port = Config::get('email_smtp_port');
+                    $mail->Username = Config::get('email_smtp_username');
+                    $mail->Password = Config::get('email_smtp_password');
+                    $mail->SMTPAutoTLS = Config::get('email_auto_tls');
+                    $mail->SMTPDebug = 0;
+                    break;
+                default:
+                    $mail->Mailer = 'mail';
+                    break;
+            }
+
+            return $mail->send();
         }
 
-        return 'No contacts found';
+        throw new \PHPMailer\PHPMailer\Exception('No contacts found');
     }
 
     /**
