@@ -539,8 +539,12 @@ class PollerQueueManager(QueueManager):
         if self.lock(device_id, timeout=self.config.poller.frequency):
             logger.info("Polling device {}".format(device_id))
 
-            args = ("-d", "-h", device_id) if self.config.debug else ("-h", device_id)
-            exit_code, output = LibreNMS.call_script("poller.php", args)
+            args = (
+                ("device:poll", device_id, "-vv")
+                if self.config.debug
+                else ("device:poll", device_id, "-q")
+            )
+            exit_code, output = LibreNMS.call_script("lnms", args)
 
             if self.config.log_output:
                 with open(
