@@ -52,12 +52,6 @@ class CustomMapSettingsRequest extends FormRequest
                     }
                 },
             ],
-            'legend_x' => 'integer',
-            'legend_y' => 'integer',
-            'legend_steps' => 'integer',
-            'legend_font_size' => 'integer',
-            'legend_hide_invalid' => 'boolean',
-            'legend_hide_overspeed' => 'boolean',
         ];
     }
 }
