@@ -104,6 +104,20 @@ class Port extends DeviceRelatedModel
         return Rewrite::shortenIfName(Rewrite::normalizeIfName($this->ifName ?: $this->ifDescr));
     }
 
+    /**
+     * Get a label containing both the ifName and ifAlias if they differ.
+     */
+    public function getFullLabel(): string
+    {
+        $label = $this->getLabel();
+
+        if ($label == $this->ifAlias || empty($this->ifAlias)) {
+            return $label;
+        }
+
+        return "$label - $this->ifAlias";
+    }
+
     /**
      * Get the description of this port
      */
@@ -338,6 +352,16 @@ class Port extends DeviceRelatedModel
         return $this->links->merge($this->remoteLinks);
     }
 
+    public function xdpLinkedPorts(): BelongsToMany
+    {
+        return $this->belongsToMany(Port::class, 'links', 'local_port_id', 'remote_port_id');
+    }
+
+    public function macLinkedPorts(): BelongsToMany
+    {
+        return $this->belongsToMany(Port::class, 'view_port_mac_links', 'port_id', 'remote_port_id');
+    }
+
     public function macAccounting(): HasMany
     {
         return $this->hasMany(MacAccounting::class, 'port_id');
