@@ -3,6 +3,7 @@
 namespace App\Models;
 
 use Illuminate\Database\Eloquent\Relations\BelongsTo;
+use Illuminate\Database\Eloquent\Relations\HasMany;
 
 class PortsFdb extends PortRelatedModel
 {
@@ -21,4 +22,9 @@ class PortsFdb extends PortRelatedModel
     {
         return $this->belongsTo(\App\Models\Vlan::class, 'vlan_id', 'vlan_id');
     }
+
+    public function ipv4Addresses(): HasMany
+    {
+        return $this->hasMany(\App\Models\Ipv4Mac::class, 'mac_address', 'mac_address');
+    }
 }
