@@ -228,6 +228,11 @@ class User extends Authenticatable
         return $this->hasMany(\App\Models\ApiToken::class, 'user_id', 'user_id');
     }
 
+    public function bills(): BelongsToMany
+    {
+        return $this->belongsToMany(\App\Models\Bill::class, 'bill_perms', 'user_id', 'bill_id');
+    }
+
     public function devices()
     {
         // pseudo relation
@@ -236,6 +241,11 @@ class User extends Authenticatable
         });
     }
 
+    public function devicesOwned(): BelongsToMany
+    {
+        return $this->belongsToMany(\App\Models\Device::class, 'devices_perms', 'user_id', 'device_id');
+    }
+
     public function deviceGroups(): BelongsToMany
     {
         return $this->belongsToMany(\App\Models\DeviceGroup::class, 'devices_group_perms', 'user_id', 'device_group_id');
@@ -247,10 +257,15 @@ class User extends Authenticatable
             return Port::query();
         } else {
             //FIXME we should return all ports for a device if the user has been given access to the whole device.
-            return $this->belongsToMany(\App\Models\Port::class, 'ports_perms', 'user_id', 'port_id');
+            return $this->portsOwned();
         }
     }
 
+    public function portsOwned(): BelongsToMany
+    {
+        return $this->belongsToMany(\App\Models\Port::class, 'ports_perms', 'user_id', 'port_id');
+    }
+
     public function dashboards(): HasMany
     {
         return $this->hasMany(\App\Models\Dashboard::class, 'user_id');
