@@ -13,8 +13,5 @@ $init_modules = ['nodb'];
 require __DIR__ . '/includes/init.php';
 
 if (App::runningInConsole()) {
-    // fill in db variables for legacy external scripts
-    Config::populateLegacyDbCredentials();
-
     echo Config::toJson();
 }
