@@ -181,30 +181,6 @@ $(document).on("click", '.collapse-neighbors', function(event)
     continued.toggle();
 });
 
-//availability-map mode change
-$(document).on("change", '#mode', function() {
-    $.post('ajax/set_map_view',
-        {
-            map_view: $(this).val()
-        },
-        function(data) {
-                location.reload();
-        },'json'
-    );
-});
-
-//availability-map device group
-$(document).on("change", '#group', function() {
-    $.post('ajax/set_map_group',
-        {
-            group_view: $(this).val()
-        },
-        function(data){
-            location.reload();
-        },'json'
-    );
-});
-
 $(document).ready(function() {
     var lines = 'on';
     $("#linenumbers").button().on("click", function() {
@@ -439,83 +415,6 @@ function destroy_map(id) {
     }
 }
 
-function populate_map_markers(map_id, group_radius = 10, status = [0,1], device_group = 0) {
-    $.ajax({
-        type: "GET",
-        url: ajax_url + '/dash/worldmap',
-        dataType: "json",
-        data: { status: status, device_group: device_group },
-        success: function (data) {
-            var redMarker = L.AwesomeMarkers.icon({
-                icon: 'server',
-                markerColor: 'red', prefix: 'fa', iconColor: 'white'
-            });
-            var blueMarker = L.AwesomeMarkers.icon({
-                icon: 'server',
-                markerColor: 'blue', prefix: 'fa', iconColor: 'white'
-            });
-            var greenMarker = L.AwesomeMarkers.icon({
-                icon: 'server',
-                markerColor: 'green', prefix: 'fa', iconColor: 'white'
-            });
-
-            var markers = data.map((device) => {
-                var markerData = {title: device.name};
-                switch (device.status) {
-                    case 0: // down
-                        markerData.icon = redMarker;
-                        markerData.zIndexOffset = 5000;
-                        break;
-                    case 3: // down + maintenance
-                        markerData.icon = blueMarker;
-                        markerData.zIndexOffset = 10000;
-                        break;
-                    default: // up
-                        markerData.icon = greenMarker;
-                        markerData.zIndexOffset = 0;
-                }
-
-                var marker = L.marker(new L.LatLng(device.lat, device.lng), markerData);
-                marker.bindPopup(`<a href="${device.url}"><img src="${device.icon}" width="32" height="32" alt=""> ${device.name}</a>`);
-                return marker;
-            });
-
-            var map = get_map(map_id);
-            if (! map.markerCluster) {
-                map.markerCluster = L.markerClusterGroup({
-                    maxClusterRadius: group_radius,
-                    iconCreateFunction: function (cluster) {
-                        var markers = cluster.getAllChildMarkers();
-                        var color = "green";
-                        var newClass = "Cluster marker-cluster marker-cluster-small leaflet-zoom-animated leaflet-clickable";
-                        for (var i = 0; i < markers.length; i++) {
-                            if (markers[i].options.icon.options.markerColor == "blue" && color != "red") {
-                                color = "blue";
-                            }
-                            if (markers[i].options.icon.options.markerColor == "red") {
-                                color = "red";
-                            }
-                        }
-                        return L.divIcon({
-                            html: cluster.getChildCount(),
-                            className: color + newClass,
-                            iconSize: L.point(40, 40)
-                        });
-                    }
-                });
-
-                map.addLayer(map.markerCluster);
-            }
-
-            map.markerCluster.clearLayers();
-            map.markerCluster.addLayers(markers);
-        },
-        error: function(error){
-            toastr.error(error.statusText);
-        }
-    });
-}
-
 function disable_map_interaction(leaflet) {
     leaflet.zoomControl?.remove();
     delete leaflet.zoomControl;
