@@ -262,28 +262,6 @@ function dbFetchRows($sql, $parameters = [])
     return [];
 }//end dbFetchRows()
 
-/**
- * This is intended to be the method used for large result sets.
- * It is intended to return an iterator, and act upon buffered data.
- *
- * @deprecated Please use Eloquent instead; https://laravel.com/docs/eloquent
- * @see https://laravel.com/docs/eloquent
- */
-function dbFetch($sql, $parameters = [])
-{
-    return dbFetchRows($sql, $parameters);
-    /*
-        // for now, don't do the iterator thing
-        $result = dbQuery($sql, $parameters);
-        if($result) {
-        // return new iterator
-        return new dbIterator($result);
-        } else {
-        return null; // ??
-        }
-     */
-}//end dbFetch()
-
 /**
  * Like fetch(), accepts any number of arguments
  * The first argument is an sprintf-ready query stringTypes
@@ -365,53 +343,6 @@ function dbFetchColumn($sql, $parameters = [])
     return [];
 }//end dbFetchColumn()
 
-/**
- * Should be passed a query that fetches two fields
- * The first will become the array key
- * The second the key's value
- *
- * @deprecated Please use Eloquent instead; https://laravel.com/docs/eloquent
- * @see https://laravel.com/docs/eloquent
- */
-function dbFetchKeyValue($sql, $parameters = [])
-{
-    $data = [];
-    foreach (dbFetch($sql, $parameters) as $row) {
-        $key = array_shift($row);
-        if (sizeof($row) == 1) {
-            // if there were only 2 fields in the result
-            // use the second for the value
-            $data[$key] = array_shift($row);
-        } else {
-            // if more than 2 fields were fetched
-            // use the array of the rest as the value
-            $data[$key] = $row;
-        }
-    }
-
-    return $data;
-}//end dbFetchKeyValue()
-
-/**
- * Legacy dbFacile indicates DB::raw() as a value wrapped in an array
- *
- * @param  array  $data
- * @return array
- *
- * @deprecated Please use Eloquent instead; https://laravel.com/docs/eloquent
- * @see https://laravel.com/docs/eloquent
- */
-function dbArrayToRaw($data)
-{
-    array_walk($data, function (&$item) {
-        if (is_array($item)) {
-            $item = Eloquent::DB()->raw(reset($item));
-        }
-    });
-
-    return $data;
-}
-
 /**
  * @deprecated Please use Eloquent instead; https://laravel.com/docs/eloquent
  * @see https://laravel.com/docs/eloquent
@@ -472,33 +403,6 @@ function dbPlaceHolders(&$values)
     return $data;
 }//end dbPlaceHolders()
 
-/**
- * @deprecated Please use Eloquent instead; https://laravel.com/docs/eloquent
- * @see https://laravel.com/docs/eloquent
- */
-function dbBeginTransaction()
-{
-    Eloquent::DB()->beginTransaction();
-}//end dbBeginTransaction()
-
-/**
- * @deprecated Please use Eloquent instead; https://laravel.com/docs/eloquent
- * @see https://laravel.com/docs/eloquent
- */
-function dbCommitTransaction()
-{
-    Eloquent::DB()->commit();
-}//end dbCommitTransaction()
-
-/**
- * @deprecated Please use Eloquent instead; https://laravel.com/docs/eloquent
- * @see https://laravel.com/docs/eloquent
- */
-function dbRollbackTransaction()
-{
-    Eloquent::DB()->rollBack();
-}//end dbRollbackTransaction()
-
 /**
  * Generate a string of placeholders to pass to fill in a list
  * result will look like this: (?, ?, ?, ?)
@@ -549,30 +453,3 @@ function dbSyncRelationship($table, $target_column = null, $target = null, $list
 
     return [$inserted, $deleted];
 }
-
-/**
- * Synchronize a relationship to a list of relations
- *
- * @param  string  $table
- * @param  array  $relationships  array of relationship pairs with columns as keys and ids as values
- * @return array [$inserted, $deleted]
- *
- * @deprecated Please use Eloquent instead; https://laravel.com/docs/eloquent
- * @see https://laravel.com/docs/eloquent
- */
-function dbSyncRelationships($table, $relationships = [])
-{
-    $changed = [[0, 0]];
-    [$target_column, $list_column] = array_keys(reset($relationships));
-
-    $grouped = [];
-    foreach ($relationships as $relationship) {
-        $grouped[$relationship[$target_column]][] = $relationship[$list_column];
-    }
-
-    foreach ($grouped as $target => $list) {
-        $changed[] = dbSyncRelationship($table, $target_column, $target, $list_column, $list);
-    }
-
-    return [array_sum(array_column($changed, 0)), array_sum(array_column($changed, 1))];
-}
