@@ -23,6 +23,8 @@
  * @author     Tony Murray <murraytony@gmail.com>
  */
 
+use App\Models\Application;
+use App\Observers\ModuleModelObserver;
 use LibreNMS\Config;
 
 echo "\nApplications: ";
@@ -56,7 +58,7 @@ d_echo('Checking for: ' . implode(', ', array_keys($results)) . PHP_EOL);
 
 // Generate a list of enabled apps and a list of all discovered apps from the db
 [$enabled_apps, $discovered_apps] = array_reduce(dbFetchRows(
-    'SELECT `app_type`,`discovered` FROM `applications` WHERE `device_id`=? ORDER BY `app_type`',
+    'SELECT `app_type`,`discovered` FROM `applications` WHERE `device_id`=? AND deleted_at IS NULL ORDER BY `app_type`',
     [$device['device_id']]
 ), function ($result, $app) {
     $result[0][] = $app['app_type'];
@@ -67,6 +69,9 @@ d_echo('Checking for: ' . implode(', ', array_keys($results)) . PHP_EOL);
     return $result;
 }, [[], []]);
 
+// enable observer for printing changes
+ModuleModelObserver::observe(\App\Models\Application::class);
+
 // Enable applications
 $current_apps = [];
 foreach ($results as $extend => $result) {
@@ -74,18 +79,13 @@ foreach ($results as $extend => $result) {
         $app = $applications[$extend];
         $current_apps[] = $app;
 
-        if (in_array($app, $enabled_apps)) {
-            echo '.';
-        } else {
-            dbInsert([
-                'device_id' => $device['device_id'],
-                'app_type' => $app,
-                'discovered' => 1,
-                'app_status' => '',
-                'app_instance' => '',
-            ], 'applications');
-
-            echo '+';
+        if (! in_array($app, $enabled_apps)) {
+            $app_obj = Application::withTrashed()->firstOrNew(['device_id' => $device['device_id'], 'app_type' => $app]);
+            if ($app_obj->trashed()) {
+                $app_obj->restore();
+            }
+            $app_obj->discovered = 1;
+            $app_obj->save();
             log_event("Application enabled by discovery: $app", $device, 'application', 1);
         }
     }
@@ -93,20 +93,10 @@ foreach ($results as $extend => $result) {
 
 // remove non-existing apps
 $apps_to_remove = array_diff($discovered_apps, $current_apps);
-$num = count($apps_to_remove);
-if ($num > 0) {
-    echo str_repeat('-', $num);
-    $vars = $apps_to_remove;
-    array_unshift($vars, $device['device_id']);
-    dbDelete(
-        'applications',
-        '`device_id`=? AND `app_type` IN ' . dbGenPlaceholders($num),
-        $vars
-    );
-    foreach ($apps_to_remove as $app) {
-        log_event("Application disabled by discovery: $app", $device, 'application', 3);
-    }
-}
+DeviceCache::getPrimary()->applications()->whereIn('app_type', $apps_to_remove)->get()->each(function (Application $app) {
+    $app->delete();
+    \App\Models\Eventlog::log("Application disabled by discovery: $app->app_type", DeviceCache::getPrimary(), 'application', \LibreNMS\Enum\Severity::Notice);
+});
 
 // clean application_metrics
 dbDeleteOrphans('application_metrics', ['applications.app_id']);
