@@ -11,7 +11,7 @@ for ($i = 1; $i <= 3; $i++) {
     $warnlimit = null;
     $limit = null;
 
-    discover_sensor($valid['sensor'], 'current', $device, $current_oid, $index, $type, $descr, '10', '1', $lowlimit, null, null, null, $current);
+    discover_sensor(null, 'current', $device, $current_oid, $index, $type, $descr, '10', '1', $lowlimit, null, null, null, $current);
 }
 
 for ($i = 1; $i <= 3; $i++) {
@@ -25,5 +25,5 @@ for ($i = 1; $i <= 3; $i++) {
     $warnlimit = null;
     $limit = null;
 
-    discover_sensor($valid['sensor'], 'current', $device, $current_oid, $index, $type, $descr, '10', '1', $lowlimit, null, null, null, $current);
+    discover_sensor(null, 'current', $device, $current_oid, $index, $type, $descr, '10', '1', $lowlimit, null, null, null, $current);
 }
