@@ -19,7 +19,7 @@ foreach (explode("\n", $psus) as $psu) {
             $descr = 'PSU ' . $current_id . ' output';
             $value = snmp_get($device, $current_oid, '-Oqv');
             $max_value = snmp_get($device, $psu_max_oid, '-Oqv');
-            discover_sensor($valid['sensor'], 'power', $device, $current_oid, $current_id, $sensor_type, $descr, 1, 1, null, null, null, $max_value, $value);
+            discover_sensor(null, 'power', $device, $current_oid, $current_id, $sensor_type, $descr, 1, 1, null, null, null, $max_value, $value);
         }
     }
 }
