@@ -26,7 +26,7 @@ foreach (explode("\n", $fans) as $fan) {
                 ];
                 create_state_index($state_name, $states);
             }
-            discover_sensor($valid['sensor'], 'state', $device, $current_oid, $current_id, $fan_state_name, $descr, 1, 1, null, null, null, null, $state, 'snmp', $current_id);
+            discover_sensor(null, 'state', $device, $current_oid, $current_id, $fan_state_name, $descr, 1, 1, null, null, null, null, $state, 'snmp', $current_id);
             create_sensor_to_state_index($device, $fan_state_name, $current_id);
         }
     }
@@ -58,7 +58,7 @@ foreach (explode("\n", $psus) as $psu) {
                 ];
                 create_state_index($state_name, $states);
             }
-            discover_sensor($valid['sensor'], 'state', $device, $current_oid, $current_id, $psu_state_name, $descr, 1, 1, null, null, null, null, $state, 'snmp', $current_id);
+            discover_sensor(null, 'state', $device, $current_oid, $current_id, $psu_state_name, $descr, 1, 1, null, null, null, null, $state, 'snmp', $current_id);
             create_sensor_to_state_index($device, $psu_state_name, $current_id);
         }
     }
