@@ -32,7 +32,7 @@ if (! empty($battery_current) || $battery_current == 0) {
     $type = 'sinetica';
     $index = '2.5.0';
 
-    discover_sensor($valid['sensor'], 'voltage', $device, $battery_oid, $index, $type, $descr, $divisor, '1', null, null, null, null, $current);
+    discover_sensor(null, 'voltage', $device, $battery_oid, $index, $type, $descr, $divisor, '1', null, null, null, null, $current);
 }
 
 $oids = snmpwalk_cache_oid_num($device, '.1.3.6.1.4.1.13891.101.3.3.1.3', []);
@@ -49,7 +49,7 @@ foreach ($oids as $oid => $data) {
     $type = 'sinetica';
     $index = '3.3.1.3.' . $current_id;
 
-    discover_sensor($valid['sensor'], 'voltage', $device, $current_oid, $index, $type, $descr, 1, 1, null, null, null, null, $current);
+    discover_sensor(null, 'voltage', $device, $current_oid, $index, $type, $descr, 1, 1, null, null, null, null, $current);
 }
 
 $oids = snmpwalk_cache_oid_num($device, '.1.3.6.1.4.1.13891.101.4.4.1.2', []);
@@ -66,5 +66,5 @@ foreach ($oids as $oid => $data) {
     $type = 'sinetica';
     $index = '4.4.1.2.' . $current_id;
 
-    discover_sensor($valid['sensor'], 'voltage', $device, $current_oid, $index, $type, $descr, 1, '1', null, null, null, null, $current);
+    discover_sensor(null, 'voltage', $device, $current_oid, $index, $type, $descr, 1, '1', null, null, null, null, $current);
 }
