@@ -958,16 +958,19 @@ function get_oxidized_nodes_list()
             //user cannot see this device, so let's skip it.
             continue;
         }
+        try {
+            // Convert UTC time string to local timezone set
+            $utc_time = $object['time'];
+            $utc_date = new DateTime($utc_time, new DateTimeZone('UTC'));
+            $local_timezone = new DateTimeZone(date_default_timezone_get());
+            $local_date = $utc_date->setTimezone($local_timezone);
 
-        // Convert UTC time string to local timezone set
-        $utc_time = $object['time'];
-        $utc_date = new DateTime($utc_time, new DateTimeZone('UTC'));
-        $local_timezone = new DateTimeZone(date_default_timezone_get());
-        $local_date = $utc_date->setTimezone($local_timezone);
-
-        // Generate local time string
-        $formatted_local_time = $local_date->format('Y-m-d H:i:s T');
-
+            // Generate local time string
+            $formatted_local_time = $local_date->format('Y-m-d H:i:s T');
+        } catch (Exception $e) {
+            // Just display the current value of $object['time'];
+            $formatted_local_time = $object['time'];
+        }
         echo '<tr>
         <td>' . $device['device_id'] . '</td>
         <td>' . $object['name'] . '</td>
