@@ -6,7 +6,7 @@ if (is_numeric($vars['id']) && ($auth || port_permitted($vars['id']))) {
     $title = generate_device_link($device);
     $title .= ' :: Port  ' . generate_port_link($port);
 
-    $graph_title = shorthost($device['hostname']) . '::' . strtolower(makeshortif($port['ifDescr']));
+    $graph_title = DeviceCache::get($device['device_id'])->shortDisplayName() . '::' . strtolower(makeshortif($port['ifDescr']));
 
     if (($port['ifAlias'] != '') && ($port['ifAlias'] != $port['ifDescr'])) {
         $title .= ', ' . \LibreNMS\Util\Clean::html($port['ifAlias'], []);
