@@ -4,7 +4,7 @@ require 'includes/html/graphs/common.inc.php';
 
 $rrd_options .= " COMMENT:'                                        Min        Max      Last\\n'";
 $rrd_options .= " DEF:sensor=$rrd_filename:sensor:AVERAGE";
-$rrd_options .= " LINE1.5:sensor#cc0000:'" . rrdtool_escape($sensor['sensor_descr'], 30) . "'";
+$rrd_options .= " LINE1.5:sensor#cc0000:'" . \LibreNMS\Data\Store\Rrd::fixedSafeDescr($sensor['sensor_descr'], 30) . "'";
 $rrd_options .= ' GPRINT:sensor:MIN:%8.0lf';
 $rrd_options .= ' GPRINT:sensor:MAX:%8.0lf';
 $rrd_options .= ' GPRINT:sensor:LAST:%8.0lf\l';
