@@ -433,6 +433,25 @@ $graphs['sagan'] = [
     'uptime',
     'alert',
 ];
+$graphs['oslv_monitor'] = [
+    'cpu_percent',
+    'mem_percent',
+    'time',
+    'procs',
+    'sizes',
+    'rss',
+    'vsz',
+    'faults',
+    'rwd_amount',
+    'ops_rwd',
+    'cows',
+    'sock',
+    'recv_sent_msgs',
+    'etime',
+    'swaps',
+    'signals_taken',
+    'switches',
+];
 $graphs['hv-monitor'] = [
     'status',
     'memory',
@@ -542,6 +561,21 @@ $graphs['ss'] = [
     'vsock',
     'xdp',
 ];
+$graphs['http_access_log_combined'] = [
+    'bytes',
+    'codes_general',
+    'codes_1xx',
+    'codes_2xx',
+    'codes_3xx',
+    'codes_4xx',
+    'codes_5xx',
+    'methods',
+    'version',
+    'refer',
+    'user',
+    'log_size',
+    'error_size',
+];
 $graphs['borgbackup'] = [
     'unique_csize',
     'total_csize',
@@ -560,6 +594,32 @@ $graphs['nfs'] = [
     'client_rpc',
     'client_cache',
 ];
+$graphs['poudriere'] = [
+    'status',
+    'phase',
+    'time',
+    'log_size',
+    'package_size',
+    'cpu_perc',
+    'mem_perc',
+    'time_comparison',
+    'user_time',
+    'system_time',
+    'rss',
+    'threads',
+    'major_faults',
+    'minor_faults',
+    'swaps',
+    'size_comparison',
+    'stack_size',
+    'data_size',
+    'text_size',
+    'read_blocks',
+    'copy_on_write_faults',
+    'context_switches_comparison',
+    'voluntary_context_switches',
+    'involuntary_context_switches',
+];
 
 echo '<div class="panel panel-default">';
 echo '<div class="panel-heading">';
@@ -571,9 +631,9 @@ $link_array = [
     'tab' => 'apps',
 ];
 
-$apps = \LibreNMS\Util\ObjectCache::applications()->flatten();
+$apps = LibreNMS\Util\ObjectCache::applications()->flatten();
 foreach ($apps as $app) {
-    $app_state = \LibreNMS\Util\Html::appStateIcon($app->app_state);
+    $app_state = LibreNMS\Util\Html::appStateIcon($app->app_state);
     if (! empty($app_state['icon'])) {
         $app_state_info = '<font color="' . $app_state['color'] . '"><i title="' . $app_state['hover_text'] . '" class="fa ' . $app_state['icon'] . ' fa-fw fa-lg" aria-hidden="true"></i></font>';
     } else {
