@@ -1,6 +1,6 @@
 <?php
 
-$vm = proxmox_vm_info(var_get('vmid'), var_get('instance'));
+$vm = proxmox_vm_info(Request::get('vmid'), Request::get('instance'));
 
 $graphs = [
     'proxmox_traffic' => 'Traffic',
@@ -23,7 +23,7 @@ foreach ($vm['ports'] as $port) {
 
         echo '<h3>' . $text . ' ' . $port['port'] . '@' . $vm['description'] . '</h3>';
 
-        echo "<tr bgcolor='$row_colour'><td colspan=5>";
+        echo '<tr><td colspan=5>';
 
         include 'includes/html/print-graphrow.inc.php';
 
