@@ -13,7 +13,7 @@
  * @author     PipoCanaja <pipocanaja@gmail.com>
  */
 
-use App\Plugins\Hooks\PortTabHook;
+use LibreNMS\Interfaces\Plugins\Hooks\PortTabHook;
 
 $pagetitle[] = 'Plugins';
 $no_refresh = true;
@@ -23,6 +23,6 @@ $no_refresh = true;
 <hr>
 <?php
 echo \LibreNMS\Plugins::call('port_container', [$device, $port]);
-PluginManager::call(PortTabHook::class, ['port' => $portModel])->each(function ($view) {
+foreach (PluginManager::call(PortTabHook::class, ['port' => $portModel]) as $view) {
     echo $view;
-});
+};
