@@ -12,7 +12,6 @@ $mailscanner = snmp_get($device, $oid, $options);
 
 [$msg_recv, $msg_rejected, $msg_relay, $msg_sent, $msg_waiting, $spam, $virus] = explode("\n", $mailscanner);
 
-$rrd_name = ['app', $name, $app->app_id];
 $rrd_def = RrdDefinition::make()
     ->addDataset('msg_recv', 'COUNTER', 0, 125000000000)
     ->addDataset('msg_rejected', 'COUNTER', 0, 12500000000)
@@ -23,15 +22,20 @@ $rrd_def = RrdDefinition::make()
     ->addDataset('virus', 'COUNTER', 0, 125000000000);
 
 $fields = [
-    'msg_recv'     => $msg_recv,
+    'msg_recv' => $msg_recv,
     'msg_rejected' => $msg_rejected,
-    'msg_relay'    => $msg_relay,
-    'msg_sent'     => $msg_sent,
-    'msg_waiting'  => $msg_waiting,
-    'spam'         => $spam,
-    'virus'        => $virus,
+    'msg_relay' => $msg_relay,
+    'msg_sent' => $msg_sent,
+    'msg_waiting' => $msg_waiting,
+    'spam' => $spam,
+    'virus' => $virus,
 ];
 
-$tags = compact('name', 'app_id', 'rrd_name', 'rrd_def');
+$tags = [
+    'name' => $name,
+    'app_id' => $app->app_id,
+    'rrd_name' => ['app', $name, $app->app_id],
+    'rrd_def' => $rrd_def,
+];
 data_update($device, 'app', $tags, $fields);
 update_application($app, $mailscanner, $fields);
