@@ -4,7 +4,7 @@
 if ($service['service_param']) {
     $nsquery = $service['service_param'];
 } else {
-    $nsquery = 'localhost';
+    $nsquery = 'localhost.';
 }
 if ($service['service_ip']) {
     $resolver = $service['service_ip'];
