@@ -51,7 +51,6 @@ return [
                 'alignment' => 'Node Alignment',
                 'edgeseparation' => 'Link Separation',
                 'reverse' => 'Reverse Arrows',
-                'enable_legend' => 'Enable Legend',
                 'saving' => 'Saving...',
                 'save_errors' => 'Save failed due to the following errors:',
                 'save_error' => 'Save failed.  Server returned error response code: :code',
@@ -62,11 +61,21 @@ return [
                 'rerender' => 'Re-Render Map',
                 'save' => 'Save Map',
                 'legend' => [
+                    'customcolours' => 'Custom Colours',
+                    'colour' => 'Colour',
+                    'colour_lower_pct' => 'Start Percent',
+                    'colour_down' => 'Device Down Colour',
+                    'colour_invalid' => 'Unknown Percent Colour',
                     'font_size' => 'Legend Text Size',
                     'steps' => 'Legend Steps',
                     'hideinvalid' => 'Hide Invalid',
                     'hideoverspeed' => 'Hide 100%+',
                 ],
+                'legend_title' => 'Legend Settings',
+                'legend_toggle' => 'Toggle Legend',
+                'zoom' => 'Pan and Zoom',
+                'dragnodes' => 'Move Nodes',
+                'physics' => 'Physics Engine',
             ],
             'node' => [
                 'new' => 'New Node',
@@ -128,7 +137,10 @@ return [
             'edge' => [
                 'new' => 'New Edge',
                 'add' => 'Add Edge',
+                'edit' => 'Edit Edge',
                 'defaults_title' => 'Edge Default Config',
+                'dynamic_width' => 'Dynamic Width',
+                'fixed_width' => 'Fixed Width',
                 'from' => 'From',
                 'to' => 'To',
                 'port_select' => 'Select Port',
@@ -161,5 +173,8 @@ return [
                 'height_pixels' => 'Height in pixels must be at least 200',
             ],
         ],
+        'widget' => [
+            'not_found' => 'No map selected.  Edit widget to select map.',
+        ],
     ],
 ];
