@@ -12,7 +12,7 @@
                             <div class="form-group row">
                                 <label for="mapname" class="col-sm-3 control-label">{{ __('map.custom.edit.map.name') }}</label>
                                 <div class="col-sm-9">
-                                    <input type="text" id="mapname" name="mapname" class="form-control input-sm" value="{{ $name ?? '' }}">
+                                    <input type="text" id="mapname" name="mapname" class="form-control input-sm">
                                 </div>
                             </div>
                             <div class="form-group row">
@@ -24,25 +24,25 @@
                             <div class="form-group row">
                                 <label for="mapwidth" class="col-sm-3 control-label">{{ __('map.custom.edit.map.width') }}</label>
                                 <div class="col-sm-9">
-                                    <input type="text" id="mapwidth" name="mapwidth" class="form-control input-sm" value="{{ $map_conf['width'] ?? '1800px' }}">
+                                    <input type="text" id="mapwidth" name="mapwidth" class="form-control input-sm">
                                 </div>
                             </div>
                             <div class="form-group row">
                                 <label for="mapheight" class="col-sm-3 control-label">{{ __('map.custom.edit.map.height') }}</label>
                                 <div class="col-sm-9">
-                                    <input type="text" id="mapheight" name="mapheight" class="form-control input-sm" value="{{ $map_conf['height'] ?? '800px' }}">
+                                    <input type="text" id="mapheight" name="mapheight" class="form-control input-sm">
                                 </div>
                             </div>
                             <div class="form-group row">
                                 <label for="mapnodealign" class="col-sm-3 control-label">{{ __('map.custom.edit.map.alignment') }}</label>
                                 <div class="col-sm-9">
-                                    <input type="number" id="mapnodealign" name="mapnodealign" class="form-control input-sm" value="{{ $node_align ?? 10 }}">
+                                    <input type="number" id="mapnodealign" name="mapnodealign" class="form-control input-sm">
                                 </div>
                             </div>
                             <div class="form-group row">
                                 <label for="mapedgesep" class="col-sm-3 control-label">{{ __('map.custom.edit.map.edgeseparation') }}</label>
                                 <div class="col-sm-9">
-                                    <input type="number" id="mapedgesep" name="mapedgesep" class="form-control input-sm" value="{{ $edge_separation ?? 10 }}">
+                                    <input type="number" id="mapedgesep" name="mapedgesep" class="form-control input-sm">
                                 </div>
                             </div>
                             <div class="form-group row">
@@ -52,33 +52,21 @@
                                 </div>
                             </div>
                             <div class="form-group row">
-                                <label for="maplegend" class="col-sm-3 control-label">{{ __('map.custom.edit.map.enable_legend') }}</label>
+                                <label for="mapopt-zoom" class="col-sm-3 control-label">{{ __('map.custom.edit.map.zoom') }}</label>
                                 <div class="col-sm-9">
-                                    <input class="form-check-input" type="checkbox" role="switch" id="maplegend" onChange="toggleMapLegend()">
+                                    <input class="form-check-input" type="checkbox" role="switch" id="mapopt-zoom">
                                 </div>
                             </div>
-                            <div class="form-group row maplegend">
-                                <label for="maplegendfontsize" class="col-sm-4 control-label">{{ __('map.custom.edit.map.legend.font_size') }}</label>
-                                <div class="col-sm-8">
-                                    <input type=number id="maplegendfontsize" class="form-control input-sm" value={{ $legend['font_size'] }} />
+                            <div class="form-group row">
+                                <label for="mapopt-dragnodes" class="col-sm-3 control-label">{{ __('map.custom.edit.map.dragnodes') }}</label>
+                                <div class="col-sm-9">
+                                    <input class="form-check-input" type="checkbox" role="switch" id="mapopt-dragnodes">
                                 </div>
                             </div>
-                            <div class="form-group row maplegend">
-                                <label for="maplegendsteps" class="col-sm-4 control-label">{{ __('map.custom.edit.map.legend.steps') }}</label>
-                                <div class="col-sm-8">
-                                    <input type=number id="maplegendsteps" class="form-control input-sm" value={{ $legend['steps'] }} />
-                                </div>
-                            </div>
-                            <div class="form-group row maplegend">
-                                <label for="maplegendhideinvalid" class="col-sm-4 control-label">{{ __('map.custom.edit.map.legend.hideinvalid') }}</label>
-                                <div class="col-sm-8">
-                                    <input class="form-check-input" type="checkbox" role="switch" id="maplegendhideinvalid">
-                                </div>
-                            </div>
-                            <div class="form-group row maplegend">
-                                <label for="maplegendhideoverspeed" class="col-sm-4 control-label">{{ __('map.custom.edit.map.legend.hideoverspeed') }}</label>
-                                <div class="col-sm-8">
-                                    <input class="form-check-input" type="checkbox" role="switch" id="maplegendhideoverspeed">
+                            <div class="form-group row">
+                                <label for="mapopt-physics" class="col-sm-3 control-label">{{ __('map.custom.edit.map.physics') }}</label>
+                                <div class="col-sm-9">
+                                    <input class="form-check-input" type="checkbox" role="switch" id="mapopt-physics">
                                 </div>
                             </div>
                             <hr>
@@ -105,6 +93,10 @@
     var edge_sep = {{$edge_separation}};
     var reverse_arrows = {{$reverse_arrows}};
     var legend = @json($legend);
+    var map_name = "{{ $name ?? '' }}";
+    var map_node_align = {{ $node_align ?? 10 }};
+    var map_edge_separation = {{ $edge_separation ?? 10 }};
+    var map_options = {{ Js::from($map_options) }};
 
     function saveMapSettings() {
         $("#map-saveButton").attr('disabled','disabled');
@@ -116,31 +108,19 @@
         var width = $("#mapwidth").val();
         var height = $("#mapheight").val();
         var node_align = $("#mapnodealign").val();
+        var post_options = structuredClone(map_options);
 
-        var mapwdith = 100;
-        if (!isNaN(width)) {
-            mapwidth = width;
-        } else if (width.includes("px")) {
-            mapwidth = width.replace("px", "");
-        } else if (width.includes("%")) {
-            mapwidth = window.innerWidth * width.replace("%", "") / 100;
+        // Fixes for known issues if the data in the DB is corrupt
+        if (Array.isArray(post_options.physics)) {
+            post_options.physics = {};
+        }
+        if (Array.isArray(post_options.interaction)) {
+            post_options.interaction = {};
         }
 
-        // Update the x and y coordinates
-        if ($("#maplegend").prop('checked')) {
-            if (legend.x < 0) {
-                legend.x = mapwidth - 50;
-                legend.y = 100;
-            }
-        } else {
-            legend.x = -1;
-            legend.y = -1;
-        }
-
-        legend.font_size = parseInt($("#maplegendfontsize").val());
-        legend.steps = parseInt($("#maplegendsteps").val());
-        legend.hide_invalid = $("#maplegendhideinvalid").prop('checked') ? 1 : 0;
-        legend.hide_overspeed = $("#maplegendhideoverspeed").prop('checked') ? 1 : 0;
+        post_options.interaction.zoomView = post_options.interaction.dragView = $("#mapopt-zoom").prop('checked');
+        post_options.interaction.dragNodes = $("#mapopt-dragnodes").prop('checked');
+        post_options.physics.enabled = $("#mapopt-physics").prop('checked');
 
         var map_reverse_arrows = $("#mapreversearrows").prop('checked') ? 1 : 0;
         var map_edge_sep = $("#mapedgesep").val();
@@ -170,12 +150,7 @@
                 node_align: node_align,
                 reverse_arrows: map_reverse_arrows,
                 edge_separation: map_edge_sep,
-                legend_x: legend.x,
-                legend_y: legend.y,
-                legend_steps: legend.steps,
-                legend_font_size: legend.font_size,
-                legend_hide_invalid: legend.hide_invalid,
-                legend_hide_overspeed: legend.hide_overspeed,
+                options: JSON.stringify(post_options),
             },
             dataType: 'json',
             type: method
@@ -197,22 +172,20 @@
         });
     }
 
-    function toggleMapLegend() {
-        if($("#maplegend").prop('checked')) {
-            $(".maplegend").show();
-        } else {
-            $(".maplegend").hide();
-        }
+    function mapSettingsReset() {
+        $("#mapreversearrows").bootstrapSwitch('state', Boolean(reverse_arrows));
+        $("#mapopt-zoom").bootstrapSwitch('state', Boolean(map_options.interaction.zoomView));
+        $("#mapopt-dragnodes").bootstrapSwitch('state', Boolean(map_options.interaction.dragNodes));
+        $("#mapopt-physics").bootstrapSwitch('state', Boolean(map_options.physics.enabled));
+        $("#mapname").val(map_name);
+        $("#mapwidth").val(network_options.width);
+        $("#mapheight").val(network_options.height);
+        $("#mapnodealign").val(map_node_align);
+        $("#mapedgesep").val(map_edge_separation);
     }
 
     $(document).ready(function () {
-        if(legend.x < 0 || legend.y < 0) {
-            $(".maplegend").hide();
-        }
-        $("#mapreversearrows").bootstrapSwitch('state', Boolean(reverse_arrows));
-        $("#maplegend").bootstrapSwitch('state', (legend.x >= 0 && legend.y >= 0));
-        $("#maplegendhideinvalid").bootstrapSwitch('state', Boolean(legend.hide_invalid));
-        $("#maplegendhideoverspeed").bootstrapSwitch('state', Boolean(legend.hide_overspeed));
+        mapSettingsReset();
         init_select2("#mapmenugroup", "custom-map-menu-group", {}, @json($menu_group ?? null), "{{ __('map.custom.edit.map.no_group') }}", {
             tags: true,
             createTag: function (params) {
